[PATCH] D26166: [Sema] Don't issue analysis-based warnings when a fatal error has occurred

Akira Hatanaka via cfe-commits cfe-commits at lists.llvm.org
Thu Nov 3 08:14:35 PDT 2016


This revision was automatically updated to reflect the committed changes.
Closed by commit rL285923: [Sema] Avoid instantiating templates only when UncompilableErrorOccurred (authored by ahatanak).

Changed prior to commit:
  https://reviews.llvm.org/D26166?vs=76521&id=76863#toc

Repository:
  rL LLVM

https://reviews.llvm.org/D26166

Files:
  cfe/trunk/lib/Sema/SemaTemplateInstantiate.cpp
  cfe/trunk/test/SemaCXX/instantiate-template-fatal-error.cpp


Index: cfe/trunk/test/SemaCXX/instantiate-template-fatal-error.cpp
===================================================================
--- cfe/trunk/test/SemaCXX/instantiate-template-fatal-error.cpp
+++ cfe/trunk/test/SemaCXX/instantiate-template-fatal-error.cpp
@@ -0,0 +1,22 @@
+// RUN: %clang_cc1 -fsyntax-only -verify -std=c++14 %s
+
+#pragma clang diagnostic fatal "-Wall"
+#pragma clang diagnostic fatal "-Wold-style-cast"
+
+template <class T> bool foo0(const long long *a, T* b) {
+  return a == (const long long*)b; // expected-error {{use of old-style cast}}
+}
+
+template<class T>
+struct S1 {
+};
+
+template<class T>
+struct S2 : S1<T> {
+  bool m1(const long long *a, T *b) const { return foo0(a, b); }
+};
+
+bool foo1(const long long *a, int *b) {
+  S2<int> s2;
+  return s2.m1(a, b);
+}
Index: cfe/trunk/lib/Sema/SemaTemplateInstantiate.cpp
===================================================================
--- cfe/trunk/lib/Sema/SemaTemplateInstantiate.cpp
+++ cfe/trunk/lib/Sema/SemaTemplateInstantiate.cpp
@@ -209,9 +209,11 @@
     sema::TemplateDeductionInfo *DeductionInfo)
     : SemaRef(SemaRef), SavedInNonInstantiationSFINAEContext(
                             SemaRef.InNonInstantiationSFINAEContext) {
-  // Don't allow further instantiation if a fatal error has occcured.  Any
-  // diagnostics we might have raised will not be visible.
-  if (SemaRef.Diags.hasFatalErrorOccurred()) {
+  // Don't allow further instantiation if a fatal error and an uncompilable
+  // error have occcured. Any diagnostics we might have raised will not be
+  // visible, and we do not need to construct a correct AST.
+  if (SemaRef.Diags.hasFatalErrorOccurred() &&
+      SemaRef.Diags.hasUncompilableErrorOccurred()) {
     Invalid = true;
     return;
   }


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D26166.76863.patch
Type: text/x-patch
Size: 1776 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20161103/d927bd67/attachment.bin>


More information about the cfe-commits mailing list